ExitCode

Enum ExitCode 

#[non_exhaustive]
pub enum ExitCode {
Show 28 variants ReadDeflate = 1, InvalidPredictionData = 2, AnalyzeFailed = 3, RecompressFailed = 4, RoundtripMismatch = 5, ReadBlock = 6, PredictBlock = 7, PredictTree = 8, RecreateBlock = 9, RecreateTree = 10, EncodeBlock = 11, InvalidCompressedWrapper = 12, ZstdError = 14, InvalidParameterHeader = 15, ShortRead = 16, OsError = 17, GeneralFailure = 18, InvalidIDat = 19, MatchNotFound = 20, InvalidDeflate = 21, NoCompressionCandidates = 22, InvalidParameter = 23, AssertionFailure = 24, NonZeroPadding = 25, PredictionFailure = 26, PlainTextLimit = 27, WebPDecodeError = 28, OutOfMemory = 29,
}

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


ReadDeflate = 1



InvalidPredictionData = 2



AnalyzeFailed = 3



RecompressFailed = 4



RoundtripMismatch = 5



ReadBlock = 6



PredictBlock = 7



PredictTree = 8



RecreateBlock = 9



RecreateTree = 10



EncodeBlock = 11



InvalidCompressedWrapper = 12



ZstdError = 14



InvalidParameterHeader = 15



ShortRead = 16



OsError = 17



GeneralFailure = 18



InvalidIDat = 19



MatchNotFound = 20



InvalidDeflate = 21

The deflate data stream is invalid or corrupt and cannot be properly read or reconstructed.



NoCompressionCandidates = 22

We couldn’t find a reasonable candidate for the version of the deflate algorithm used to compress the data. No gain would be had from recompressing the data since the amount of correction data would be larger than the original data.



InvalidParameter = 23



AssertionFailure = 24

panic in rust code



NonZeroPadding = 25

Non-zero padding found in deflate, which we currently don’t handle



PredictionFailure = 26

Unable to predict the sequence of compression. Doesn’t mean that the deflate content was invalid, but just that we don’t handle some of the rare corner cases.



PlainTextLimit = 27

Plain text memory limit exceeded



WebPDecodeError = 28

WebP decoding error



OutOfMemory = 29

Out of memory

Implementations

Source

impl ExitCode

pub fn as_integer_error_code(self) -> i32

Converts the error code into an integer for use as an error code when returning from a C API.