TokenPredictorParameters

Struct TokenPredictorParameters 

pub struct TokenPredictorParameters {
Show 14 fields pub matches_to_start_detected: bool, pub very_far_matches_detected: bool, pub window_bits: u32, pub strategy: PreflateStrategy, pub nice_length: u32, pub add_policy: DictionaryAddPolicy, pub max_token_count: u16, pub zlib_compatible: bool, pub max_dist_3_matches: u32, pub matching_type: MatchingType, pub max_chain: u32, pub min_len: u32, pub hash_algorithm: HashAlgorithm, pub block_type_strategy: BlockTypeStrategy,
}

Fields

matches_to_start_detected: bool

Zlib does not match to first byte of a file in order to reserve 0 for the end of chain

very_far_matches_detected: bool

if there are matches that have a distance larger than window_size - MAX_MATCH. Zlib does not allow these.

window_bits: u32strategy: PreflateStrategynice_length: u32add_policy: DictionaryAddPolicy

if something, then we use the “fast” compressor, which only adds smaller substrings to the dictionary

max_token_count: u16zlib_compatible: boolmax_dist_3_matches: u32matching_type: MatchingTypemax_chain: u32min_len: u32hash_algorithm: HashAlgorithmblock_type_strategy: BlockTypeStrategy